notes/notesui/notesmodel/src/notesmodel.cpp
changeset 57 bb2d3e476f29
parent 55 2c54b51f39c4
child 75 7ac58b2aae6f
--- a/notes/notesui/notesmodel/src/notesmodel.cpp	Mon Jul 26 13:54:38 2010 +0530
+++ b/notes/notesui/notesmodel/src/notesmodel.cpp	Mon Aug 09 18:30:52 2010 +0530
@@ -1023,8 +1023,13 @@
 			// Set the to-do done icon.
 			QList<QVariant> iconList;
 			iconList.append(HbIcon("qtg_small_todo_done"));
-			// To-do is already completed. No need to set alarm.
-			iconList.append(QVariant(QVariant::Invalid));
+			if (1 == entry.priority()) {
+				// Set the High Priority icon if priority is high or else not.
+				iconList.append(HbIcon("qtg_small_priority_high"));
+			} else {
+				// To-do is already completed. No need to set alarm.
+				iconList.append(QVariant(QVariant::Invalid));
+			}
 
 			// Set the icons.
 			mSourceModel->setData(